.. SPDX-FileCopyrightText: 2022 Simone Persiani <iosonopersia@gmail.com>
..
.. SPDX-License-Identifier: ISC

oc\_ocdm.graph.entities.bibliographic package
=============================================

Modules
-------
.. toctree::
   :maxdepth: 1

   bibliographic/oc_ocdm.graph.entities.bibliographic.agent_role
   bibliographic/oc_ocdm.graph.entities.bibliographic.bibliographic_reference
   bibliographic/oc_ocdm.graph.entities.bibliographic.bibliographic_resource
   bibliographic/oc_ocdm.graph.entities.bibliographic.citation
   bibliographic/oc_ocdm.graph.entities.bibliographic.discourse_element
   bibliographic/oc_ocdm.graph.entities.bibliographic.pointer_list
   bibliographic/oc_ocdm.graph.entities.bibliographic.reference_annotation
   bibliographic/oc_ocdm.graph.entities.bibliographic.reference_pointer
   bibliographic/oc_ocdm.graph.entities.bibliographic.resource_embodiment
   bibliographic/oc_ocdm.graph.entities.bibliographic.responsible_agent
